==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/cy/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Fedrith y defnyddiwr yma mewngofnodi',
    'activated_disabled_help_text' => 'Nid yw\'n bosib newid statws eich cyfrif.',
    'assets_user'       => 'Asedu wedi aseinio i :name',
    'bulk_update_warn'	=> 'Rydych am golygu manylion :user_count o ddefnyddwyr. Nodwch, nid yw\'n bosib i chi newid manylion eich cyfrif yma. Rhaid i chi golygu manylion eich cyfrif yn unigol.',
    'bulk_update_help'	=> 'Mae\'r ffurflen hon yn caniatáu ichi ddiweddaru nifer o defnyddwyr ar unwaith. Llenwch y meysydd sydd angen i chi eu newid yn unig. Bydd unrhyw bwlch a adewir yn wag yn aros yr un fath.',
    'current_assets'    => 'Asedau wedi aseinio ar hyn o bryd i\'r defnyddiwr yma',
    'clone'             => 'Dyblygu Defnyddiwr',
    'contact_user'      => 'Cyswllt :name',
    'edit'              => 'Golygu Defnyddiwr',
    'filetype_info'     => 'Math o ffeiliau a caniateir yw png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, a rar.',
    'history_user'      => 'Hanes ar gyfer :name',
	'info'				=> 'Gwybodaeth',
    'restore_user'		=> 'Cliciwch yma yw adfer.',
    'last_login'        => 'Mewngofnodi Diwethaf',
    'ldap_config_text'  => 'Gweler Gweinyddiaeth > Gosodiadau am gosodiadau LDAP. Mae\'r lleoliad (dewisol) yn cael ei osod am unrhyw defnyddwyr sydd yn cael ei mewnforio.',
    'print_assigned'    => 'Argraffu Asedau',
    'software_user'     => 'Meddalwedd allan i :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Gweld Defnyddiwr :name',
    'usercsv'           => 'Ffeil CSV',
    'two_factor_admin_optin_help' => 'Mae eich gosodiadau admin yn caniatau gorfodaeth dewisol o dilysiant dau-factor.  ',
    'two_factor_enrolled' => 'Dyfais D2F Wedi Ymuno ',
    'two_factor_active'   => 'D2F Weithredol ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/cy/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Fedrith y defnyddiwr yma mewngofnodi',
    'activated_disabled_help_text' => 'Nid yw\'n bosib newid statws eich cyfrif.',
    'assets_user'       => 'Asedu wedi aseinio i :name',
    'bulk_update_warn'	=> 'Rydych am golygu manylion :user_count o ddefnyddwyr. Nodwch, nid yw\'n bosib i chi newid manylion eich cyfrif yma. Rhaid i chi golygu manylion eich cyfrif yn unigol.',
    'bulk_update_help'	=> 'Mae\'r ffurflen hon yn caniatáu ichi ddiweddaru nifer o defnyddwyr ar unwaith. Llenwch y meysydd sydd angen i chi eu newid yn unig. Bydd unrhyw bwlch a adewir yn wag yn aros yr un fath.',
    'current_assets'    => 'Asedau wedi aseinio ar hyn o bryd i\'r defnyddiwr yma',
    'clone'             => 'Dyblygu Defnyddiwr',
    'contact_user'      => 'Cyswllt :name',
    'edit'              => 'Golygu Defnyddiwr',
    'filetype_info'     => 'Math o ffeiliau a caniateir yw png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, a rar.',
    'history_user'      => 'Hanes ar gyfer :name',
    'info'				=> 'Gwybodaeth',
    'restore_user'		=> 'Cliciwch yma yw adfer.',
    'last_login'        => 'Mewngofnodi Diwethaf',
    'ldap_config_text'  => 'Gweler Gweinyddiaeth > Gosodiadau am gosodiadau LDAP. Mae\'r lleoliad (dewisol) yn cael ei osod am unrhyw defnyddwyr sydd yn cael ei mewnforio.',
    'print_assigned'    => 'Argraffu Asedau',
    'software_user'     => 'Meddalwedd allan i :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Gweld Defnyddiwr :name',
    'usercsv'           => 'Ffeil CSV',
    'two_factor_admin_optin_help' => 'Mae eich gosodiadau admin yn caniatau gorfodaeth dewisol o dilysiant dau-factor.  ',
    'two_factor_enrolled' => 'Dyfais D2F Wedi Ymuno ',
    'two_factor_active'   => 'D2F Weithredol ',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
